@@ -1,10 +1,10 @@
 from base64 import b64decode
+from json import dumps
 from re import match, sub
 
 import aiofiles
 from aiohttp import ClientSession
 from dotmap import DotMap
-from json import dumps
 from pyrogram.types import Message, User
 
 
@@ -36,7 +36,7 @@ class Arq:
     ___________
 
         ARQ(API_URL: str, API_KEY: str, AioHTTPSession)
-    
+
     """
 
     def __init__(
@@ -72,10 +72,14 @@ class Arq:
             response = await resp.json()
         return DotMap(response)
 
-    async def _post_data(self, route, data):
+    async def _post_data(self, route, data, header=None):
+        headers = {"X-API-KEY": self.api_key}
+        if header:
+            for key, value in header.items():
+                headers[key] = value
         async with self.session.post(
             f"{self.api_url}/{route}",
-            headers={"X-API-KEY": self.api_key},
+            headers=headers,
             data=data,
         ) as resp:
             if resp.status in (401, 403):
@@ -85,29 +89,6 @@ class Arq:
             response = await resp.json()
         return DotMap(response)
 
-    async def deezer(self, query: str, count: int = 1, format: int = 3):
-        """
-        Returns An Object.
-
-                Parameters:
-                        query (str): Query to search
-                        count (int): Number of results to return
-                        format (int): Quality [Bitrate] of songs.
-                                      Available formats:  1 - MP3 128kbit,
-                                                          3 - MP3 320kbit,
-                                                          9 - Lossless(FLAC),
-                                      Defaults to 3, MP3 320Kbps.
-                Returns:
-                        results: Results which you can access with dot notation, Ex - results[result_number].url
-
-                        result[result_number].title | .id | .source | .duration | .thumbnail | .thumbnailBig |.artist
-                            .artistPictures | .url
-
-        """
-        return await self._fetch(
-            "deezer", query=query, count=count, format=format
-        )
-
     async def torrent(self, query: str):
         """
         Returns An Object.
@@ -159,19 +140,6 @@ class Arq:
         """
         return await self._fetch("youtube", query=query)
 
-    async def ytdl(self, url: str):
-        """
-        Returns An Object.
-
-                Parameters:
-                        url (str): Youtube video url
-                Returns:
-                        Result object (str): Results which you can access with dot notation, Ex - results[result_number].thumbnails
-
-                        result[result_number].id | .thumbnail | .title | .video
-        """
-        return await self._fetch("ytdl", url=url)
-
     async def wall(self, query: str):
         """
         Returns An Object.
@@ -235,17 +203,6 @@ class Arq:
             thumbsize=thumbsize,
         )
 
-    async def phdl(self, url: str):
-        """
-        Returns An Object.
-
-                Parameters:
-                        url (str): URL To Fetch
-                Returns:
-                        result object (str): Result
-        """
-        return await self._fetch("phdl", url=url)
-
     async def luna(self, query: str, id: int = 0):
         """
         Returns An Object.
@@ -297,7 +254,9 @@ class Arq:
                         results.prediction | .spam | .ham
         """
         data = dumps({"messages": messages})
-        return await self._post_data("nlp", data)
+        return await self._post_data(
+            "nlp", data, {"Content-Type": "application/json"}
+        )
 
     async def nsfw_scan(self, url: str = None, file: str = None):
         """
@@ -503,5 +462,17 @@ class Arq:
         """
         return await self._fetch("spellcheck", text=text)
 
+    async def asq(self, question: str):
+        """
+        Returns An Object.
+
+                Parameters:
+                        question (str): A question.
+                Returns:
+                        result -> Answer
+        """
+        return await self._fetch("asq", question=question)
+
+
 # Backwards compatibility
 ARQ = Arq
